@@ -397,7 +397,7 @@ BOOL cmd_sweep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             if(item && item->mUserObject) {
                 if(item != gCurrentObject || strcmp(var_name, SUOBJECT(item).mName) != 0) {
-                    if(hash_erase(current_object, var_name)) {
+                    if(uobject_erase(current_object, var_name)) {
                         runinfo->mRCode = 0;
                     }
                 }
