@@ -175,7 +175,7 @@ BOOL cmd_def(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             sObject* reciever = runinfo->mCurrentObject;
             sObject* fun = access_object(command->mArgsRuntime[1], &reciever, runinfo->mRunningObject);
             if(fun && TYPE(fun) == T_FUN) {
-                char* source = SBLOCK(fun).mSource;
+                char* source = SBLOCK(SFUN(fun).mBlock).mSource;
                 if(!fd_write(nextout, source, strlen(source))) {
                     err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -243,7 +243,7 @@ BOOL cmd_class(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             sObject* reciever = runinfo->mCurrentObject;
             sObject* klass = access_object(command->mArgsRuntime[1], &reciever, runinfo->mRunningObject);
             if(klass && TYPE(klass) == T_CLASS) {
-                char* source = SBLOCK(klass).mSource;
+                char* source = SBLOCK(SCLASS(klass).mBlock).mSource;
                 if(!fd_write(nextout, source, strlen(source))) {
                     err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
