@@ -518,6 +518,39 @@ static BOOL read_one_argument(char** p, sBuf* buf, char* sname, int* sline, BOOL
 
             skip_spaces(p);
         }
+        /// redirect error out ///
+        else if(**p == '2' && *(*p+1) == '>') {
+            if(buf->mBuf[0] != 0) {
+                /// message passing ///
+                if(buf->mMessagePassing) {
+                    if(!sCommand_add_message(command, MANAGED buf->mBuf)) {
+                        err_msg("too many message", sname, *sline, buf->mBuf);
+                        FREE(buf->mBuf);
+                        return FALSE;
+                    }
+                }
+                else if(!add_argument_to_command(buf, command, sname, sline)) {
+                    return FALSE;
+                }
+
+                memset(buf, 0, sizeof(sBuf));
+                buf->mBuf = MALLOC(64);
+                buf->mBuf[0] = 0;
+                buf->mSize = 64;
+            }
+
+            (*p)++;
+
+            if(**p == '>') {
+                buf->mRedirect = REDIRECT_ERROR_APPEND;
+                (*p)++;
+            }
+            else {
+                buf->mRedirect = REDIRECT_ERROR_OUT;
+            }
+
+            skip_spaces(p);
+        }
         /// glob ///
         else if(command->mArgsNum > 0 && **p == '[' || **p == '?' || **p == '*') {
             add_char_to_buf(buf, **p);
