@@ -614,7 +614,12 @@ char** readline_on_complete(const char* text, int start, int end)
                 (void)vector_pop_back(gStackFrames);
                 readline_signal();
 
-                fd_split(nextout, kLF);
+                enum eLineField lf;
+                if(fd_guess_lf(nextout, &lf)) {
+                    fd_split(nextout, lf);
+                } else {
+                    fd_split(nextout, kLF);
+                }
 
                 gUserCompletionNextout = nextout;
                 char** result = rl_completion_matches(text, user_completion);
