@@ -24,6 +24,7 @@ sObject* gStdout;
 sObject* gStderr;
 
 sObject* gGlobalPipe;
+//sObject* gPipes;
 
 enum eLineField gLineField;
 enum eKanjiCode gKanjiCode;
@@ -34,6 +35,7 @@ sObject* gJobs;
 
 void run_init(enum eAppType app_type)
 {
+    //gPipes = LIST_NEW_STACK();
     gAppType = app_type;
     gStdin = FD_NEW_STACK(kFDKindBuf, 0);
     gStdout = FD_NEW_STACK(kFDKindBuf, 0);
@@ -71,6 +73,8 @@ sObject* fd_new_from_stack(int kind, int fd)
 
         SFD(self).fdbuf.mLines = VECTOR_NEW_MALLOC(32);
         SFD(self).fdbuf.mReadedLineNumber = 0;
+
+        //list_push_front(gPipes, self);
     }
 
     return self;
@@ -87,6 +91,8 @@ void fd_delete_stack(sObject* self)
         vector_delete_malloc(SFD(self).fdbuf.mLines);
 
         FREE(SFD(self).fdbuf.mBuf);
+
+        //list_erase(list_find(gPipes, self), gPipes);
     }
 }
 
@@ -124,6 +130,66 @@ BOOL bufsiz_write(int fd, char* buf, int buf_size)
     return TRUE;
 }
 
+BOOL fd_guess_lf(sObject* self, enum eLineField* lf)
+{
+    *lf = -1;
+    char* p = SFD(self).fdbuf.mBuf;
+
+    while(*p) {
+        if(*p == '\a') {
+            *lf = kBel;
+            return TRUE;
+        }
+        else {
+            p++;
+        }
+    }
+
+    if(*lf == -1) {
+        p = SFD(self).fdbuf.mBuf;
+
+        while(*p) {
+            if(*p == '\r' && *(p+1) == '\n') {
+                *lf = kCRLF;
+                return TRUE;
+            }
+            else {
+                p++;
+            }
+        }
+    }
+
+    if(*lf == -1) {
+        p = SFD(self).fdbuf.mBuf;
+
+        while(*p) {
+            if(*p == '\r') {
+                *lf = kCR;
+                return TRUE;
+            }
+            else {
+                p++;
+            }
+        }
+    }
+
+    if(*lf == -1) {
+        p = SFD(self).fdbuf.mBuf;
+
+        while(*p) {
+            if(*p == '\n') {
+                *lf = kLF;
+                return TRUE;
+            }
+            else {
+                p++;
+            }
+        }
+    }
+
+    return FALSE;
+}
+
 void fd_split(sObject* self, enum eLineField lf)
 {
     assert(TYPE(self) == T_FD && SFD(self).mKind == kFDKindBuf);
@@ -1205,7 +1271,12 @@ static BOOL statment_tree(sStatment* statment, sObject* pipein, sObject* pipeout
         /// line context pipe ///
         else {
             nextin = FD_NEW_STACK(kFDKindBuf, 0);
-            fd_split(pipein, kLF);
+            enum eLineField lf;
+            if(fd_guess_lf(pipein, &lf)) {
+                fd_split(pipein, lf);
+            } else {
+                fd_split(pipein, kLF);
+            }
             if(line_number < 0) line_number += vector_count(SFD(pipein).fdbuf.mLines)+1;
             if(line_number < 0) line_number = 0;
             if(line_number > vector_count(SFD(pipein).fdbuf.mLines)) line_number = vector_count(SFD(pipein).fdbuf.mLines);
