@@ -427,4 +427,66 @@ int uobject_count(sObject* self)
    assert(TYPE(self) == T_UOBJECT);
 
    return SUOBJECT(self).mCounter;
-}   
+}
+
+static void erase_from_list(sObject* self, uobject_it* rit)
+{
+   assert(TYPE(self) == T_UOBJECT);
+   if(rit == SUOBJECT(self).mEntryIt) {
+      SUOBJECT(self).mEntryIt = rit->mNextIt;
+   }
+   else {
+      uobject_it* it = SUOBJECT(self).mEntryIt;
+
+      while(it->mNextIt) {
+         if(it->mNextIt == rit) {
+            it->mNextIt = it->mNextIt->mNextIt;
+            break;
+         }
+            
+         it = it->mNextIt;
+      }
+   }
+}
+
+BOOL uobject_erase(sObject* self, char* key)
+{
+   assert(TYPE(self) == T_UOBJECT);
+   const unsigned int hash_value = get_uobject_value(self, key);
+   uobject_it* it = SUOBJECT(self).mTable[hash_value];
+   
+   if(it == NULL)
+      ;
+   else if(strcmp(it->mKey, key) == 0) {
+      uobject_it* it2 = SUOBJECT(self).mEntryIt;   
+      SUOBJECT(self).mTable[ hash_value ] = it->mCollisionIt;
+
+      erase_from_list(self, it);
+      
+      uobject_it_release(it, self);
+
+      SUOBJECT(self).mCounter--;
+
+      return TRUE;
+   }
+   else {
+      uobject_it* prev_it = it;
+      it = it->mCollisionIt;
+      while(it) {
+         if(strcmp(it->mKey, key) == 0) {
+            prev_it->mCollisionIt = it->mCollisionIt;
+            erase_from_list(self, it);
+            uobject_it_release(it, self);
+            SUOBJECT(self).mCounter--;
+            
+            return TRUE;
+         }
+         
+         prev_it = it;
+         it = it->mCollisionIt;
+      }
+   }
+
+   return FALSE;
+}
+
